UserSysAchievementLevel class

Annotations

Constructors

UserSysAchievementLevel()
UserSysAchievementLevel.fromJson(Map<String, dynamic> json)
factory

Properties

exp ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ String?
getter/setter pair
integral ↔ int?
getter/setter pair
level ↔ int?
getter/setter pair
maxExp ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited